About
=====

`PIC tools` is a collection of tools to ease PIC development. PIC is
family of microcontrollers made by `Microchip`_.

Features:

- A PIC programmer based on an `Arduino Due`_. Today only the
  `PIC32MM0256GPM064`_ family is supported.

Project homepage: https://github.com/eerimoq/pictools

Documentation: http://pictools.readthedocs.org/en/latest

Contributing
============

#. Fork the repository.

#. Install prerequisites.

   .. code-block:: text

      pip install -r requirements.txt

#. Implement the new feature or bug fix.

#. Create a pull request.

.. _Arduino Due: https://store.arduino.cc/arduino-due

.. _Microchip: https://www.microchip.com/

.. _PIC32MM0256GPM064: https://www.microchip.com/wwwproducts/en/PIC32MM0256GPM064
